19. Changelog — Jscatter 1.3.0.7 documentation

# 19. Changelog

The latest version of this file can be found at the master branch of the Jscatter repository.

1.3.0

  - added decoratedCoreShell

  - added fuzzyCylinder

  - added inhomogeneousSphere

  - added randomLattice

  - added fractal structure factor

  - added Schulz-Zimm distribution

  - added showlastErrPlot2D

  - added headless mode for cluster usage

  - added imagehash

  - added persistent columnIndex through write/reread data

  - added inhomogeneousCylinder

  - added Two Yukawa structure factor

  - added prism formfactor

  - added multidimensional quadrature (cubature)

  - added ornsteinZernike

  - added orientedCloudScattering

  - added polymerCorLength

  - added DAB

1.2.0

  - removed python 2.7 compatibility and changes for Python3

  - smear as decorator to automatically extend over edges

  - smear handles beamProfiles in data for fitting with different smearing in data

  - added weakPolyelectrolyte

  - added multiParDistributedAverage

  - cloudscattering allows different formfactors

  - added linearPearls

1.1.0

  - added citation reference to Jscatter paper in PlosOne

  - added offset detector calibration for sasImage

  - azimuthal average in sasImage

  - lattice from CIF files with atomic coordinates

1.0.0

  - stable release

0.9.5

  - changes for Windows compatibility

0.9.4

  - changes for numpy==1.16 compatibility

  - added installation description for Windows Subsystem for Linux

  - added Ipython Notebooks and direct link to myBinder as live demo

0.9.3

  - added guinierPorod3d guinierPorod

0.9.2

  - added radial interpolation to sasImage.asdataArray

  - improved getBeamWidth and desmear

  - added more test

  - changes from inspection

  - orientedLatticeStructureFactor now with OpenMP in Fortran

  - added example_2DFitting_CrystalPeaks

0.9.1

  - added Changelog